package org.apache.bcel.util;

package .tmp;

import java.lang.ref.SoftReference;
import java.util.HashMap;
import java.util.Map;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.util.AbstractClassPathRepository;
import org.apache.bcel.util.ClassPath;

public class MemorySensitiveClassPathRepository extends AbstractClassPathRepository {
  private final Map<String, SoftReference<JavaClass>> loadedClasses = new HashMap<>();
  
  public MemorySensitiveClassPathRepository(ClassPath path) {
    super(path);
  }
  
  public void clear() {
    this.loadedClasses.clear();
  }
  
  public JavaClass findClass(String className) {
    SoftReference<JavaClass> ref = this.loadedClasses.get(className);
    if (ref == null)
      return null; 
    return ref.get();
  }
  
  public void removeClass(JavaClass clazz) {
    this.loadedClasses.remove(clazz.getClassName());
  }
  
  public void storeClass(JavaClass clazz) {
    this.loadedClasses.put(clazz.getClassName(), new SoftReference<>(clazz));
    clazz.setRepository(this);
  }
}
